@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: cheapskate
 version: 0.1.0.5
-id: cheapskate-0.1.0.5-6650c88db577f6af6e10e8b013bfd5bc
-key: cheap_8GyTDdKDxkR9TVf2IY0Wz6
+id: cheapskate-0.1.0.5-7055e2cbe829e9d125b1898db0fa9d43
+key: cheap_9sTZMUKevcsIxVukW34SPL
 license: BSD3
 copyright: (C) 2012-2013 John MacFarlane
 maintainer: jgm@berkeley.edu
@@ -31,7 +31,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/cheapskate-0.1.0.5
 library-dirs: /usr/lib/ghc-7.10.3/site-local/cheapskate-0.1.0.5
 data-dir: /usr/share/arm-linux-ghc-7.10.3/cheapskate-0.1.0.5
-hs-libraries: HScheapskate-0.1.0.5-8GyTDdKDxkR9TVf2IY0Wz6
+hs-libraries: HScheapskate-0.1.0.5-9sTZMUKevcsIxVukW34SPL
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-html-0.8.1.1-196db2ddcb827bc04473411dd00dd5eb
@@ -41,7 +41,7 @@ depends:
     syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     uniplate-1.6.12-474087ddfa30ffe8f83d021d3c4c23e6
-    xss-sanitize-0.3.5.7-6c3c3bcb4d13c9ca0347038667ddbff4
+    xss-sanitize-0.3.5.7-e5c809552f485f0cae8f01d1b991e326
 haddock-interfaces: /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
 haddock-html: /usr/share/doc/haskell-cheapskate/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
